const path = require('node:path')
const fs = require('node:fs')
const webpack = require('webpack')
const TerserPlugin = require('terser-webpack-plugin')

function getDirectories(srcpath) {
  return fs
    .readdirSync(srcpath)
    .filter(item => fs.statSync(path.join(srcpath, item)).isDirectory())
}

module.exports = []
getDirectories('./js/ckeditor5_plugins').forEach((dir) => {
  const bc = {
    mode: 'production',
    optimization: {
      minimize: true,
      minimizer: [
        new TerserPlugin({
          terserOptions: {
            format: {
              comments: false,
            },
          },
          test: /\.ts(\?.*)?$/i,
          extractComments: false,
        }),
      ],
      moduleIds: 'named',
    },
    resolve: {
      extensions: ['.ts', '.js', '.json'],
      extensionAlias: {
        '.js': ['.js', '.ts'],
      },
    },
    entry: {
      path: path.resolve(
        __dirname,
        'js/ckeditor5_plugins',
        dir,
        'src/index.ts',
      ),
    },
    output: {
      path: path.resolve(__dirname, './js/build'),
      filename: `${dir}.js`,
      library: ['CKEditor5', dir],
      libraryTarget: 'umd',
      libraryExport: 'default',
    },
    plugins: [
      new webpack.DllReferencePlugin({
        // manifest: require('./node_modules/ckeditor5/build/ckeditor5-dll.manifest.json'),
        manifest: require('ckeditor5/build/ckeditor5-dll.manifest.json'),
        scope: 'ckeditor5/src',
        name: 'CKEditor5.dll',
      }),
    ],
    module: {
      rules: [
        {
          test: /\.ts/,
          use: 'ts-loader',
        },
        {
          test: /\.svg$/,
          use: 'raw-loader',
        },
      ],
    },
  }

  module.exports.push(bc)
})
